@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  module: system usage statistics
@@ -7,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2011-2023 Univention GmbH
+# Copyright 2011-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -44,7 +43,7 @@ import socket
 import subprocess
 import tempfile
 import traceback
-from typing import Any, Callable, Dict, List, Union  # noqa: F401
+from collections.abc import Callable
 
 import apt_pkg
 import dns.exception
@@ -65,7 +64,7 @@ CMD_DISABLE_EXEC = ['/usr/share/univention-updater/disable-apache2-umc']
 RE_HOSTNAME = re.compile(r'^[a-z]([a-z0-9-]*[a-z0-9])*(\.([a-z0-9]([a-z0-9-]*[a-z0-9])*[.])*[a-z0-9]([a-z0-9-]*[a-z0-9])*)?$')
 
 
-def get_master_dns_lookup() -> Dict:
+def get_master_dns_lookup() -> dict:
     # DNS lookup for the Primary Directory Node entry
     msg = None
     fqdn = None
@@ -93,8 +92,8 @@ def get_master_dns_lookup() -> Dict:
 
 class HostSanitizer(StringSanitizer):
 
-    def _sanitize(self, value: str, name: str, further_args: List[str]) -> str:
-        value = super(HostSanitizer, self)._sanitize(value, name, further_args)
+    def _sanitize(self, value: str, name: str, further_args: list[str]) -> str:
+        value = super()._sanitize(value, name, further_args)
         try:
             return socket.getfqdn(value)
         except socket.gaierror:
@@ -102,7 +101,7 @@ class HostSanitizer(StringSanitizer):
             self.raise_validation_error(_('The entered FQDN is not a valid value'))
 
 
-class Progress(object):
+class Progress:
 
     def __init__(self, max_steps=100):
         self.reset(max_steps)
@@ -116,7 +115,7 @@ class Progress(object):
         self.errors = []
         self.critical = False
 
-    def poll(self) -> Dict:
+    def poll(self) -> dict:
         return {
             "finished": self.finished,
             "steps": 100 * float(self.steps) / self.max_steps,
@@ -150,7 +149,7 @@ class Progress(object):
         self.steps += steps
 
 
-def _dummyFunc(*args: List) -> None:
+def _dummyFunc(*args: list) -> None:
     """dummy function that does nothing"""
 
 
@@ -174,7 +173,7 @@ def system_join(
 
 
 def run_join_scripts(
-        scripts: List, force: bool, username: str, password: str, info_handler: Callable = _dummyFunc,
+        scripts: list, force: bool, username: str, password: str, info_handler: Callable = _dummyFunc,
         error_handler: Callable = _dummyFunc, critical_handler: Callable = _dummyFunc,
         step_handler: Callable = _dummyFunc, component_handler: Callable = _dummyFunc) -> None:
     with tempfile.NamedTemporaryFile() as passwordFile:
@@ -190,7 +189,7 @@ def run_join_scripts(
 
         if scripts:
             # if scripts are provided only execute them instead of running all join scripts
-            cmd += ['--run-scripts'] + scripts
+            cmd += ['--run-scripts', *scripts]
         else:
             # we need the number of join scripts for the progressbar
             scripts = os.listdir(INSTDIR)
@@ -201,7 +200,7 @@ def run_join_scripts(
 
 
 def run(
-        cmd: List, steps_per_script: float, info_handler: Callable = _dummyFunc, error_handler: Callable = _dummyFunc,
+        cmd: list, steps_per_script: float, info_handler: Callable = _dummyFunc, error_handler: Callable = _dummyFunc,
         critical_handler: Callable = _dummyFunc, step_handler: Callable = _dummyFunc, component_handler: Callable = _dummyFunc) -> None:
     # disable restart of UMC server/web-server
     MODULE.info('disabling restart of UMC server/web-server')
@@ -229,7 +228,7 @@ def run(
             if matches:
                 message = matches.groupdict().get('message')
                 error_handler(_("The system join process could not be completed:<br/><br/><i>%s</i><br/><br/> More details can be found in the log file <i>/var/log/univention/join.log</i>.<br/>Please retry after resolving any conflicting issues.") % message)
-                if message.startswith('ssh-login for') or message.startswith('binddn for'):
+                if message.startswith(('ssh-login for', 'binddn for')):
                     # invalid credentials or non existent user
                     # do a critical error, the script will stop here
                     critical_handler(True)
@@ -268,7 +267,7 @@ def run(
                 fd = select.select([process.stdout], [], [])[0][0]
             except IndexError:
                 continue  # not ready / no further data
-            except select.error as exc:
+            except OSError as exc:
                 if exc.args[0] == errno.EINTR:
                     continue
                 raise
@@ -277,7 +276,7 @@ def run(
             line = fd.read().decode('utf-8', 'replace')
             eof = not line
             buf += line
-            lines, newline, buf = buf.rpartition('\n')
+            lines, _newline, buf = buf.rpartition('\n')
 
             # parse completed joinscript executions
             for line in lines.splitlines():
@@ -339,7 +338,7 @@ class Instance(Base):
             return False
 
     @simple_response
-    def query(self) -> List[str]:
+    def query(self) -> list[str]:
         """collects status about join scripts"""
         # unjoined system?
         if not self._joined:
@@ -357,7 +356,7 @@ class Instance(Base):
 
         # check for unconfigured scripts
         process = subprocess.Popen(['/usr/sbin/univention-check-join-status'], shell=False, stdout=subprocess.PIPE)
-        stdout, stderr = process.communicate()
+        stdout, _stderr = process.communicate()
         if process.returncode == 0:
             return list(files.values())
 
@@ -385,7 +384,7 @@ class Instance(Base):
         return self._joined
 
     @simple_response
-    def progress(self) -> Dict:
+    def progress(self) -> dict:
         return self.progress_state.poll()
 
     @simple_response
@@ -409,14 +408,14 @@ class Instance(Base):
     def _lock(self) -> None:
         try:
             open(LOCKFILE, 'a').close()
-        except (IOError, OSError) as ex:
+        except OSError as ex:
             MODULE.warn(f'_lock: {ex}')
 
     def _unlock(self) -> None:
         try:
             if self._running:
                 os.unlink(LOCKFILE)
-        except (IOError, OSError) as ex:
+        except OSError as ex:
             MODULE.warn(f'_unlock: {ex}')
 
     def __del__(self) -> None:
@@ -425,13 +424,13 @@ class Instance(Base):
     # TODO __finalize__?
 
     @simple_response
-    def logview(self) -> List[str]:
+    def logview(self) -> list[str]:
         """Returns the last 2MB of the join.log file"""
         with open(LOGFILE, 'rb') as fd:
             size = 2097152
             try:
                 fd.seek(max(os.stat(fd.name).st_size - size, 0))
-            except IOError:
+            except OSError:
                 pass
             return fd.read(size).decode('utf-8', 'replace')
 
@@ -468,7 +467,7 @@ class Instance(Base):
                 critical_handler=self.progress_state.critical_handler,
             )
 
-        def _finished(thread, result: Union[None, BaseException]) -> None:
+        def _finished(thread, result: None | BaseException) -> None:
             MODULE.info('Finished joining')
             self._unlock()
             self.progress_state.info = _('finished...')
@@ -519,7 +518,7 @@ class Instance(Base):
                 critical_handler=self.progress_state.critical_handler,
             )
 
-        def _finished(thread, result: Union[None, BaseException]) -> None:
+        def _finished(thread, result: None | BaseException) -> None:
             MODULE.info('Finished running join scripts')
             self._unlock()
             self.progress_state.info = _('finished...')
